summaryrefslogtreecommitdiffstats
path: root/chrome/browser/autocomplete/autocomplete_edit.h
diff options
context:
space:
mode:
authorpkasting@google.com <pkasting@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-08-28 17:20:26 +0000
committerpkasting@google.com <pkasting@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-08-28 17:20:26 +0000
commit7ec93dfb306b62e48cdf2498f4a2b5074074969a (patch)
treeaeebf066a7bf48f1f7f41ae622f036d25c861bc3 /chrome/browser/autocomplete/autocomplete_edit.h
parentff677bcb3e08bb8be774ca69f1dd961b8c8eb490 (diff)
downloadchromium_src-7ec93dfb306b62e48cdf2498f4a2b5074074969a.zip
chromium_src-7ec93dfb306b62e48cdf2498f4a2b5074074969a.tar.gz
chromium_src-7ec93dfb306b62e48cdf2498f4a2b5074074969a.tar.bz2
Split the AutocompletePopup into model and view classes, step 1.
The just adds "Model" and "View" to the end of the current classname, leaves everything in the same files, and doesn't really change or remove any functionality, creation order, ownership semantics, etc. In other words, it's basically just moving some code around to get things split into two classes, and the harder work comes later. Also removes/trims some overly long comments, fixes a couple comment errors I noticed, and trims one or two bits of logic to be shorter. What really needs review the most is the high-level decisions about how to split data and functionality between the two classes. BUG=1343512 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@1492 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/autocomplete/autocomplete_edit.h')
-rw-r--r--chrome/browser/autocomplete/autocomplete_edit.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/chrome/browser/autocomplete/autocomplete_edit.h b/chrome/browser/autocomplete/autocomplete_edit.h
index 3b919d0..7d13409 100644
--- a/chrome/browser/autocomplete/autocomplete_edit.h
+++ b/chrome/browser/autocomplete/autocomplete_edit.h
@@ -20,7 +20,7 @@
#include "chrome/views/menu.h"
#include "webkit/glue/window_open_disposition.h"
-class AutocompletePopup;
+class AutocompletePopupModel;
class CommandController;
class Profile;
class TabContents;
@@ -181,8 +181,7 @@ class AutocompleteEdit
// |alternate_nav_url|, if non-empty, contains the alternate navigation URL
// for |url|. See comments on AutocompleteResult::GetAlternateNavURL().
//
- // |selected_line| is passed to AutocompletePopup::LogOpenedURL(); see
- // comments there.
+ // |selected_line| is passed to SendOpenNotification(); see comments there.
//
// If the URL was expanded from a keyword, |keyword| is that keyword.
//
@@ -251,8 +250,8 @@ class AutocompleteEdit
// send us events that we should treat as if they were events on us.
void HandleExternalMsg(UINT msg, UINT flags, const CPoint& screen_point);
// Called back by the AutocompletePopup when any relevant data changes. This
// rolls together several separate pieces of data into one call so we can
// update all the UI efficiently:
// |text| is either the new temporary text (if |is_temporary_text| is true)
// from the user manually selecting a different match, or the inline
@@ -577,7 +576,7 @@ class AutocompleteEdit
Controller* controller_;
// The Popup itself.
- scoped_ptr<AutocompletePopup> popup_;
+ scoped_ptr<AutocompletePopupModel> popup_;
// When true, the location bar view is read only and also is has a slightly
// different presentation (font size / color). This is used for popups.
@@ -251,8 +250,8 @@ class AutocompleteEdit
// send us events that we should treat as if they were events on us.
void HandleExternalMsg(UINT msg, UINT flags, const CPoint& screen_point);
- // Called back by the AutocompletePopup when any relevant data changes. This
- // rolls together several separate pieces of data into one call so we can
+ // Called back by the AutocompletePopupModel when any relevant data changes.
+ // This rolls together several separate pieces of data into one call so we can
// update all the UI efficiently:
// |text| is either the new temporary text (if |is_temporary_text| is true)